@@ -86,7 +86,8 @@ func (mv *Mlrval) ArrayGet(mindex *Mlrval) Mlrval {
 	if !mindex.IsInt() {
 		return *ERROR
 	}
-	value := arrayGetAliased(&mv.arrayval, int(mindex.intval))
+	arrayval := mv.intf.([]*Mlrval)
+	value := arrayGetAliased(&arrayval, int(mindex.intf.(int64)))
 	if value == nil {
 		return *ABSENT
 	} else {
@@ -116,15 +117,17 @@ func (mv *Mlrval) ArrayPut(mindex *Mlrval, value *Mlrval) {
 		os.Exit(1)
 	}
 
-	ok := arrayPutAliased(&mv.arrayval, int(mindex.intval), value)
+	arrayval := mv.intf.([]*Mlrval)
+	ok := arrayPutAliased(&arrayval, int(mindex.intf.(int64)), value)
 	if !ok {
 		fmt.Fprintf(
 			os.Stderr,
 			"mlr: array index %d out of bounds %d..%d\n",
-			mindex.intval, 1, len(mv.arrayval),
+			mindex.intf.(int64), 1, len(arrayval),
 		)
 		os.Exit(1)
 	}
+	mv.intf = arrayval
 }
 
 // ----------------------------------------------------------------
@@ -213,7 +216,8 @@ func (mv *Mlrval) ArrayAppend(value *Mlrval) {
 		// Silent no-ops are not good UX ...
 		return
 	}
-	mv.arrayval = append(mv.arrayval, value)
+	mv.intf = append(mv.intf.([]*Mlrval), value)
+
 }
 
 // ================================================================
@@ -222,7 +226,7 @@ func (mv *Mlrval) MapGet(key *Mlrval) Mlrval {
 		return *ERROR
 	}
 
-	mval, err := mv.mapval.GetWithMlrvalIndex(key)
+	mval, err := mv.intf.(*Mlrmap).GetWithMlrvalIndex(key)
 	if err != nil { // xxx maybe error-return in the API
 		return *ERROR
 	}
@@ -243,9 +247,9 @@ func (mv *Mlrval) MapPut(key *Mlrval, value *Mlrval) {
 	}
 
 	if key.IsString() {
-		mv.mapval.PutCopy(key.printrep, value)
+		mv.intf.(*Mlrmap).PutCopy(key.printrep, value)
 	} else if key.IsInt() {
-		mv.mapval.PutCopy(key.String(), value)
+		mv.intf.(*Mlrmap).PutCopy(key.String(), value)
 	}
 	// TODO: need to be careful about semantics here.
 	// Silent no-ops are not good UX ...
@@ -291,19 +295,25 @@ func (mv *Mlrval) PutIndexed(indices []*Mlrval, rvalue *Mlrval) error {
 	lib.InternalCodingErrorIf(len(indices) < 1)
 
 	if mv.IsMap() {
-		return putIndexedOnMap(mv.mapval, indices, rvalue)
+		return putIndexedOnMap(mv.intf.(*Mlrmap), indices, rvalue)
 
 	} else if mv.IsArray() {
-		return putIndexedOnArray(&mv.arrayval, indices, rvalue)
+		arrayval := mv.intf.([]*Mlrval)
+		retval := putIndexedOnArray(&arrayval, indices, rvalue)
+		mv.intf = arrayval
+		return retval
 
 	} else {
 		baseIndex := indices[0]
 		if baseIndex.IsString() {
 			*mv = *FromEmptyMap()
-			return putIndexedOnMap(mv.mapval, indices, rvalue)
+			return putIndexedOnMap(mv.intf.(*Mlrmap), indices, rvalue)
 		} else if baseIndex.IsInt() {
 			*mv = *FromEmptyArray()
-			return putIndexedOnArray(&mv.arrayval, indices, rvalue)
+			arrayval := mv.intf.([]*Mlrval)
+			retval := putIndexedOnArray(&arrayval, indices, rvalue)
+			mv.intf = arrayval
+			return retval
 		} else {
 			return errors.New(
 				"mlr: only maps and arrays are indexable; got " + mv.GetTypeName(),
@@ -326,7 +336,7 @@ func putIndexedOnMap(baseMap *Mlrmap, indices []*Mlrval, rvalue *Mlrval) error {
 					".",
 			)
 		}
-		*baseMap = *rvalue.mapval.Copy()
+		*baseMap = *rvalue.intf.(*Mlrmap).Copy()
 		return nil
 	}
 
@@ -379,21 +389,21 @@ func putIndexedOnArray(
 				".",
 		)
 	}
-	zindex, inBounds := UnaliasArrayIndex(baseArray, int(mindex.intval))
+	zindex, inBounds := UnaliasArrayIndex(baseArray, int(mindex.intf.(int64)))
 
 	if numIndices == 1 {
 		// If last index, then assign.
 		if inBounds {
 			(*baseArray)[zindex] = rvalue.Copy()
-		} else if mindex.intval == 0 {
+		} else if mindex.intf.(int64) == 0 {
 			return errors.New("mlr: zero indices are not supported. Indices are 1-up.")
-		} else if mindex.intval < 0 {
+		} else if mindex.intf.(int64) < 0 {
 			return errors.New("mlr: Cannot use negative indices to auto-lengthen arrays.")
 		} else {
 			// Array is [a,b,c] with mindices 1,2,3. Length is 3. Zindices are 0,1,2.
 			// Given mindex is 4.
-			LengthenMlrvalArray(baseArray, int(mindex.intval))
-			zindex := mindex.intval - 1
+			LengthenMlrvalArray(baseArray, int(mindex.intf.(int64)))
+			zindex := mindex.intf.(int64) - 1
 			(*baseArray)[zindex] = rvalue.Copy()
 		}
 		return nil
@@ -420,14 +430,14 @@ func putIndexedOnArray(
 
 			return (*baseArray)[zindex].PutIndexed(indices[1:], rvalue)
 
-		} else if mindex.intval == 0 {
+		} else if mindex.intf.(int64) == 0 {
 			return errors.New("mlr: zero indices are not supported. Indices are 1-up.")
-		} else if mindex.intval < 0 {
+		} else if mindex.intf.(int64) < 0 {
 			return errors.New("mlr: Cannot use negative indices to auto-lengthen arrays.")
 		} else {
 			// Already allocated but needs to be longer
-			LengthenMlrvalArray(baseArray, int(mindex.intval))
-			zindex := mindex.intval - 1
+			LengthenMlrvalArray(baseArray, int(mindex.intf.(int64)))
+			zindex := mindex.intf.(int64) - 1
 			return (*baseArray)[zindex].PutIndexed(indices[1:], rvalue)
 		}
 	}
@@ -438,10 +448,13 @@ func (mv *Mlrval) RemoveIndexed(indices []*Mlrval) error {
 	lib.InternalCodingErrorIf(len(indices) < 1)
 
 	if mv.IsMap() {
-		return removeIndexedOnMap(mv.mapval, indices)
+		return removeIndexedOnMap(mv.intf.(*Mlrmap), indices)
 
 	} else if mv.IsArray() {
-		return removeIndexedOnArray(&mv.arrayval, indices)
+		arrayval := mv.intf.([]*Mlrval)
+		retval := removeIndexedOnArray(&arrayval, indices)
+		mv.intf = arrayval
+		return retval
 
 	} else {
 		return errors.New(
@@ -505,7 +518,7 @@ func removeIndexedOnArray(
 				".",
 		)
 	}
-	zindex, inBounds := UnaliasArrayIndex(baseArray, int(mindex.intval))
+	zindex, inBounds := UnaliasArrayIndex(baseArray, int(mindex.intf.(int64)))
 
 	// If last index, then unset.
 	if numIndices == 1 {
@@ -513,7 +526,7 @@ func removeIndexedOnArray(
 			leftSlice := (*baseArray)[0:zindex]
 			rightSlice := (*baseArray)[zindex+1 : len((*baseArray))]
 			*baseArray = append(leftSlice, rightSlice...)
-		} else if mindex.intval == 0 {
+		} else if mindex.intf.(int64) == 0 {
 			return errors.New("mlr: zero indices are not supported. Indices are 1-up.")
 		} else {
 			// TODO: improve wording
@@ -523,7 +536,7 @@ func removeIndexedOnArray(
 		// More indices remain; recurse
 		if inBounds {
 			return (*baseArray)[zindex].RemoveIndexed(indices[1:])
-		} else if mindex.intval == 0 {
+		} else if mindex.intf.(int64) == 0 {
 			return errors.New("mlr: zero indices are not supported. Indices are 1-up.")
 		} else {
 			// TODO: improve wording
@@ -640,12 +653,12 @@ func BsearchMlrvalArrayForAscendingInsert(
 
 // NewMlrvalForAutoDeepen is for auto-deepen of nested maps in things like
 //
-//   $foo[1]["a"][2]["b"] = 3
+//	$foo[1]["a"][2]["b"] = 3
 //
 // Autocreated levels are maps.  Array levels can be explicitly created e.g.
 //
-//   $foo[1]["a"] ??= []
-//   $foo[1]["a"][2]["b"] = 3
+//	$foo[1]["a"] ??= []
+//	$foo[1]["a"][2]["b"] = 3
 func NewMlrvalForAutoDeepen(mvtype MVType) (*Mlrval, error) {
 	if mvtype == MT_STRING || mvtype == MT_INT {
 		empty := FromEmptyMap()
@@ -659,13 +672,13 @@ func NewMlrvalForAutoDeepen(mvtype MVType) (*Mlrval, error) {
 
 func (mv *Mlrval) Arrayify() *Mlrval {
 	if mv.IsMap() {
-		if mv.mapval.IsEmpty() {
+		if mv.intf.(*Mlrmap).IsEmpty() {
 			return mv
 		}
 
 		convertible := true
 		i := 0
-		for pe := mv.mapval.Head; pe != nil; pe = pe.Next {
+		for pe := mv.intf.(*Mlrmap).Head; pe != nil; pe = pe.Next {
 			sval := strconv.Itoa(i + 1) // Miller user-space indices are 1-up
 			i++
 			if pe.Key != sval {
@@ -675,9 +688,9 @@ func (mv *Mlrval) Arrayify() *Mlrval {
 		}
 
 		if convertible {
-			arrayval := make([]*Mlrval, mv.mapval.FieldCount)
+			arrayval := make([]*Mlrval, mv.intf.(*Mlrmap).FieldCount)
 			i := 0
-			for pe := mv.mapval.Head; pe != nil; pe = pe.Next {
+			for pe := mv.intf.(*Mlrmap).Head; pe != nil; pe = pe.Next {
 				arrayval[i] = pe.Value.Copy()
 				i++
 			}
@@ -690,9 +703,11 @@ func (mv *Mlrval) Arrayify() *Mlrval {
 	} else if mv.IsArray() {
 		// TODO: comment (or rethink) that this modifies its inputs!!
 		output := mv.Copy()
-		for i := range mv.arrayval {
-			output.arrayval[i] = output.arrayval[i].Arrayify()
+		arrayval := mv.intf.([]*Mlrval)
+		for i := range arrayval {
+			arrayval[i] = arrayval[i].Arrayify()
 		}
+		mv.intf = arrayval
 		return output
 
 	} else {
